@@ -6,9 +6,11 @@
 
 #define INSTALL_DBGPKG_SHELL_PATH "/usr/share/deepin-debug-config/shell/installdbg.sh"
 #define CONFIG_COREDUMP_SHELL_PATH "/usr/share/deepin-debug-config/shell/setting_coredump.sh"
-#define CONFIG_SHELL_PATH "/usr/share/deepin-debug-config/shell"
-#define MODULES_DEBUG_CONFIG_PATH "/usr/share/deepin-debug-config/deepin-debug-config.d"
+#define CONFIG_SHELL_PATH "/usr/share/deepin-debug-config/shell/"
+#define MODULES_DEBUG_CONFIG_PATH "/usr/share/deepin-debug-config/deepin-debug-config.d/"
 #define MODULES_DEBUG_LEVELS_PATH "/var/lib/deepin-debug-config/deepin-debug-levels.cfg"
+#define MODULES_DEBUG_LEVELS_FILENAME_BAK "/var/lib/deepin-debug-config/deepin-debug-levels.cfg.old"
+#define MODULES_INIT_CONFIG_PATH "/usr/share/deepin-debug-config/deepin-debug-config.d/"
 #define DEFAULT_CORE_PATH "/var/lib/systemd/coredump/"
 
 #define CONFIG_SHELL_IN_CODE_PATH "out/deepin-debug-config/shell"
