@@ -5,8 +5,8 @@ failmsg_zh="调试模式配置失败"
 rebootmsg="The debug mode configuration is completed, please restart the system to take effect."
 rebootmsg_zh="调试模式配置完成，请重启系统生效"
 
-sucessmsg="The debug mode configuration is completed and has taken effect."
-sucessmsg_zh="调试模式配置完成，已经生效"
+successmsg="The debug mode configuration is completed and has taken effect."
+successmsg_zh="调试模式配置完成，已经生效"
 
 if [ $1 == "SetDebug" ]; then
 	msg="${2}msg"
